/*
 * 15:01:57 22/06/99
 *
 * SwingPad.java - A simple demo of JextTextAreaLite component
 * Copyright (C) 1998-1999 Romain Guy
 * powerteam@chez.com
 * www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import javax.swing.JMenu;
import javax.swing.JFrame;
import java.awt.Dimension;
import java.awt.FontMetrics;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;
import java.awt.BorderLayout;
import java.awt.event.KeyEvent;
import javax.swing.JScrollPane;
import javax.swing.JOptionPane;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.ActionListener;
import javax.swing.ScrollPaneConstants;
import com.chez.powerteam.java.tools.JextTextAreaLite;

/**
 * SwingPad is a simple text editor, but fully functionnal
 */

public class SwingPad extends JFrame implements ActionListener
{
  private JextTextAreaLite textArea;
  private JMenuItem newMenu, openMenu, saveMenu, saveAsMenu, quitMenu,
                    undoMenu, redoMenu, copyMenu, cutMenu, pasteMenu, findMenu, selectAllMenu,
                    aboutMenu;

  SwingPad()
  {
    super("SwingPad - A Swing Notepad");

    textArea = new JextTextAreaLite();
    JScrollPane scroller = new JScrollPane(textArea, ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS, ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS);
    FontMetrics fm = getFontMetrics(textArea.getFont());
    scroller.getViewport().setPreferredSize(new Dimension(80 * fm.charWidth('m'), 20 * fm.getHeight()));
    getContentPane().add(BorderLayout.CENTER, scroller);

    JMenuBar menuBar = new JMenuBar();
    JMenu fileMenu = new JMenu("File");
    fileMenu.setMnemonic('F');

    JMenu editMenu = new JMenu("Edit");
    editMenu.setMnemonic('E');

    JMenu SwingPadMenu = new JMenu("SwingPad");
    SwingPadMenu.setMnemonic('V');

    newMenu = new JMenuItem("New");
    newMenu.addActionListener(this);
    newMenu.setMnemonic('N');
    newMenu.setAccelerator(KeyStroke.getKeyStroke('N', 2));

    openMenu = new JMenuItem("Open");
    openMenu.addActionListener(this);
    openMenu.setMnemonic('O');
    openMenu.setAccelerator(KeyStroke.getKeyStroke('O', 2));

    saveMenu = new JMenuItem("Save");
    saveMenu.addActionListener(this);
    saveMenu.setMnemonic('S');
    saveMenu.setAccelerator(KeyStroke.getKeyStroke('S', 2));

    saveAsMenu = new JMenuItem("Save As");
    saveAsMenu.addActionListener(this);
    saveAsMenu.setMnemonic('A');
    saveAsMenu.setAccelerator(KeyStroke.getKeyStroke('E', 2));

    quitMenu = new JMenuItem("Quit");
    quitMenu.addActionListener(this);
    quitMenu.setMnemonic('Q');
    quitMenu.setAccelerator(KeyStroke.getKeyStroke('Q', 2));

    undoMenu = new JMenuItem("Undo");
    undoMenu.addActionListener(this);
    undoMenu.setMnemonic('U');
    undoMenu.setAccelerator(KeyStroke.getKeyStroke('Z', 2));

    redoMenu = new JMenuItem("Redo");
    redoMenu.addActionListener(this);
    redoMenu.setMnemonic('R');
    redoMenu.setAccelerator(KeyStroke.getKeyStroke('Y', 2));

    copyMenu = new JMenuItem("Copy");
    copyMenu.addActionListener(this);
    copyMenu.setMnemonic('C');
    copyMenu.setAccelerator(KeyStroke.getKeyStroke('C', 2));

    cutMenu = new JMenuItem("Cut");
    cutMenu.addActionListener(this);
    cutMenu.setMnemonic('T');
    cutMenu.setAccelerator(KeyStroke.getKeyStroke('X', 2));

    pasteMenu = new JMenuItem("Paste");
    pasteMenu.addActionListener(this);
    pasteMenu.setMnemonic('P');
    pasteMenu.setAccelerator(KeyStroke.getKeyStroke('V', 2));

    findMenu = new JMenuItem("Find");
    findMenu.addActionListener(this);
    findMenu.setMnemonic('F');
    findMenu.setAccelerator(KeyStroke.getKeyStroke('F', 2));

    selectAllMenu = new JMenuItem("Select All");
    selectAllMenu.addActionListener(this);
    selectAllMenu.setMnemonic('A');
    selectAllMenu.setAccelerator(KeyStroke.getKeyStroke('A', 2));

    aboutMenu = new JMenuItem("About");
    aboutMenu.addActionListener(this);
    aboutMenu.setMnemonic('A');
    aboutMenu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F1, 0));

    fileMenu.add(newMenu);
    fileMenu.add(openMenu);
    fileMenu.addSeparator();
    fileMenu.add(saveMenu);
    fileMenu.add(saveAsMenu);
    fileMenu.addSeparator();
    fileMenu.add(quitMenu);
    menuBar.add(fileMenu);

    editMenu.add(undoMenu);
    editMenu.add(redoMenu);
    editMenu.addSeparator();
    editMenu.add(copyMenu);
    editMenu.add(cutMenu);
    editMenu.add(pasteMenu);
    editMenu.addSeparator();
    editMenu.add(findMenu);
    editMenu.add(selectAllMenu);
    menuBar.add(editMenu);

    SwingPadMenu.add(aboutMenu);
    menuBar.add(SwingPadMenu);

    setJMenuBar(menuBar);

    addWindowListener(new WindowAdapter()
    {
      public void windowClosing(WindowEvent e)
      {
        System.exit(0);
      }
    });

    pack();

    Dimension screen = getToolkit().getScreenSize();
    int x = (screen.width - getWidth()) / 2;
    int y = (screen.height - getHeight()) / 2;
    setLocation(x, y);

    setVisible(true);
  }

  public void actionPerformed(ActionEvent evt)
  {
    Object obj = evt.getSource();
    if (obj instanceof JMenuItem)
    {
      if (obj == newMenu)
      {
        textArea.newFile();
        setTitle("SwingPad - A Swing Notepad");
      } else if (obj == openMenu) {
        String tmp = JextTextAreaLite.chooseFile(this, JextTextAreaLite.OPEN);
        if (tmp != null)
        {
          textArea.open(tmp);
          setTitle(textArea.getCurrentFile());
        }
      } else if (obj == saveMenu)
        textArea.save(textArea.getCurrentFile());
      else if (obj == saveAsMenu)
      {
        textArea.saveContent();
        setTitle(textArea.getCurrentFile());
      } else if (obj == quitMenu)
        System.exit(0);
      else if (obj == undoMenu && textArea.getUndo().canUndo())
        textArea.getUndo().undo();
      else if (obj == redoMenu && textArea.getUndo().canRedo())
        textArea.getUndo().redo();
      else if (obj == copyMenu)
        textArea.copy();
      else if (obj == cutMenu)
        textArea.cut();
      else if (obj == pasteMenu)
        textArea.paste();
      else if (obj == selectAllMenu)
        textArea.selectAll();
      else if (obj == findMenu)
      {
        String response = JOptionPane.showInputDialog(this, "Expression:", "Find...", JOptionPane.QUESTION_MESSAGE);
        if (response != null)
          textArea.find(response, textArea.getCaretPosition(), true);
      } else if (obj == aboutMenu)
        JOptionPane.showMessageDialog(this, "SwingPad - A Swing Notepad\n" +
        "(C) 1999 Romain Guy\n\nwww.chez.com/powerteam\npowerteam@chez.com");
    }
  }

  private JextTextAreaLite getTextArea()
  {
    return textArea;
  }

  public static void main(String args[])
  {
    SwingPad visualize = new SwingPad();
    if (args.length > 0) visualize.getTextArea().open(args[0]);
  }
}

// End of SwingPad.java
